#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : moonshot
# @Time         : 2024/11/21 17:13
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : 文件url 或者 文件id
import mimetypes

from meutils.pipe import *
from meutils.io.files_utils import to_bytes
from meutils.llm.openai_utils import to_openai_params
from meutils.str_utils.regular_expression import parse_url

from openai import OpenAI, AsyncOpenAI
from meutils.schemas.openai_types import chat_completion, chat_completion_chunk, ChatCompletionRequest, CompletionUsage

moonshot_client = AsyncOpenAI(
    api_key=os.getenv("MOONSHOT_API_KEY"),
    base_url=os.getenv("MOONSHOT_BASE_URL")
)


# moonshot_client.files.

# len(moonshot_client.files.list().data)

class Completions(object):

    def __init__(self, api_key: Optional[str] = None):
        self.api_key = api_key

    @staticmethod
    @alru_cache(ttl=15 * 60)
    async def file_extract(file):  # "https://oss.ffire.cc/files/招标文件备案表（第二次）.pdf"
        """todo 定时删除文件"""
        filename = Path(file).name
        mime_type, _ = mimetypes.guess_type(filename)  # mime_type = "application/octet-stream"
        file: bytes = await to_bytes(file)

        file_object = await moonshot_client.files.create(
            # file=file,
            # file=("filename.pdf", file),
            file=(filename, file, mime_type),
            purpose="file-extract"
        )
        logger.debug(file_object)

        response = await moonshot_client.files.content(file_id=file_object.id)
        return response.text

    async def create(self, request: ChatCompletionRequest):
        """[{'role': 'user', 'content': 'hi'}]
        {"type": "file_url", "file_url": {"url": "https://oss.ffire.cc/files/招标文件备案表（第二次）.pdf", "detai": "auto"}}"""

        # logger.debug(request.urls)
        if request.urls:
            files = await asyncio.gather(*map(self.file_extract, request.urls))

            for file_content in files:
                request.system_messages.append({
                    "role": "system",
                    "content": file_content,
                })

            request.messages = request.system_messages + [{'role': 'user', 'content': request.last_content}]

        elif isinstance(request.last_content, str) and (urls := parse_url(request.last_content)):
            logger.debug(urls)

            url = urls[-1]
            request.last_content = request.last_content.replace(url, '')

            files = await asyncio.gather(*map(self.file_extract, urls))

            for file_content in files:
                request.system_messages.append({
                    "role": "system",
                    "content": file_content,
                })

            request.messages = request.system_messages + [{'role': 'user', 'content': request.last_content}]

        logger.debug(request)

        data = to_openai_params(request)
        return await AsyncOpenAI(api_key=self.api_key).chat.completions.create(**data)


# data: {"event": "message", "task_id": "900bbd43-dc0b-4383-a372-aa6e6c414227", "id": "663c5084-a254-4040-8ad3-51f2a3c1a77c", "answer": "Hi", "created_at": 1705398420}\n\n
if __name__ == '__main__':
    c = Completions()

    request = ChatCompletionRequest(
        # model="qwen-turbo-2024-11-01",
        # model="claude-3-5-sonnet-20241022",
        model="gpt-4o-mini",

        messages=[
            {
                'role': 'system',
                'content': '你是一个文件问答助手'
            },
            # {
            #     'role': 'user',
            #     # 'content': {
            #     #     "type": "file_url",
            #     #     "file_url": {"url": "https://oss.ffire.cc/files/招标文件备案表（第二次）.pdf", "detai": "auto"}
            #     # },
            #     'content': [
            #         {
            #             "type": "text",
            #             "text": "这个文件讲了什么？"
            #         },
            #         # 多轮的时候要剔除
            #         {
            #             "type": "file_url",
            #             "file_url": {"url": "https://oss.ffire.cc/files/招标文件备案表（第二次）.pdf", "detai": "auto"}
            #         }
            #     ]
            # },

            {
                'role': 'user',
                # 'content': {
                #     "type": "file_url",
                #     "file_url": {"url": "https://oss.ffire.cc/files/招标文件备案表（第二次）.pdf", "detai": "auto"}
                # },
                'content': "https://oss.ffire.cc/files/%E6%8B%9B%E6%A0%87%E6%96%87%E4%BB%B6%E5%A4%87%E6%A1%88%E8%A1%A8%EF%BC%88%E7%AC%AC%E4%BA%8C%E6%AC%A1%EF%BC%89.pdf 这个文件讲了什么？",

            },

            # {'role': 'assistant', 'content': "好的"},
            # {
            #     'role': 'user',
            #     # 'content': {
            #     #     "type": "file_url",
            #     #     "file_url": {"url": "https://oss.ffire.cc/files/招标文件备案表（第二次）.pdf", "detai": "auto"}
            #     # },
            #     'content': [
            #         {
            #             "type": "text",
            #             "text": "错了 继续回答"
            #         },
            #         # {
            #         #     "type": "file_url",
            #         #     "file_url": {"url": "https://oss.ffire.cc/files/招标文件备案表（第二次）.pdf", "detai": "auto"}
            #         # }
            #     ]
            # }
        ]

    )

    arun(c.create(request))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : utils
# @Time         : 2024/6/12 08:34
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  :

from meutils.pipe import *
from meutils.oss.minio_oss import Minio

from PIL import Image, ImageDraw


def crop_polygon(image: Union[str, bytes], outline_points, inline_points):
    if isinstance(image, bytes):
        image = io.BytesIO(image)

    # 打开图像
    img = Image.open(image)

    # 创建一个与原图大小相同的黑色遮罩
    mask = Image.new('L', img.size, 0)

    # 在遮罩上绘制白色多边形
    for points in outline_points:
        ImageDraw.Draw(mask).polygon(points, outline=1, fill=255)

    for points in inline_points:
        ImageDraw.Draw(mask).polygon(points, outline=1, fill=0)

    # 将遮罩应用到原图
    output = Image.new('RGBA', img.size, (0, 0, 0, 0))
    output.paste(img, (0, 0), mask)

    # # 将 PIL Image 转换为字节
    # buffer = io.BytesIO()
    # output.save(buffer, format="PNG")
    # byte_data = buffer.getvalue()
    #
    # return byte_data
    return output


def crop_image(
        image: Union[Path, str, bytes],

        width: Optional[int] = None,
        height: Optional[int] = None,
        x: int = 0,
        y: int = 0,

        debug: bool = False
):
    """
        crop_image(image="https://sfile.chatglm.cn/testpath/4f520e7f-c2f5-5555-8d1f-4fda0fec0e9d_0.png", height=950, debug=True)

    :param image:
    :param width:
    :param height:
    :param x:
    :param y:
    :param debug:
    :return:
    """
    if isinstance(image, bytes):
        image = io.BytesIO(image)

    elif isinstance(image, str) and image.startswith("http"):
        response = httpx.get(image)
        image = io.BytesIO(response.content)

    image = Image.open(image)  # .convert('RGB')

    width = width or image.width
    height = height or image.height
    cropped_image = image.crop((x, y, x + width, y + height))

    if debug:
        logger.debug(image.size)
        logger.debug(cropped_image.size)
        cropped_image.show()

    return cropped_image  # .save('output.png')


def crop_image_and_upload(
        image: Union[Path, str, bytes],

        width: Optional[int] = None,
        height: Optional[int] = None,
        x: int = 0,
        y: int = 0,

        debug: bool = False,

        file_id: Optional[str] = None
):
    # 创建一个 BytesIO 对象用于保存字节数据
    # byte_io = io.BytesIO()

    # 将图像保存到 BytesIO 对象中
    # image.save(byte_io, format='PNG')
    # 获取字节数据
    # byte_data = byte_io.getvalue()

    image = crop_image(image, width, height, x, y, debug)

    file_id = file_id or shortuuid.random()
    filename = f"{file_id}.png"
    image.save(filename)

    # 上传
    client = Minio()
    client.fput_object('files', filename, file_path=filename, content_type='image/png')

    # 删除临时文件
    Path(filename).unlink(True)
    return client.get_file_url(filename)


def del_watermark():  # 去水印
    import poimage
    # poimage = try_import("poimage")
    # 支持jpg、png等所有图片格式
    poimage.del_watermark(
        input_image="img.png",
        output_image='img_.png'
    )


if __name__ == '__main__':
    # (left, top, right, bottom)

    # 调用该函数传入图片路径、裁剪起始点坐标(x, y)以及宽度和高度
    # crop_image("yuanbao.jpeg", height= 998, debug=True)
    # crop_image("zhipu.png", 0, 0, 1024, 950)
    # crop_image(Path("yuanbao.jpeg").read_bytes(), height=998, debug=True)

    # r = requests.get("https://sfile.chatglm.cn/testpath/4f520e7f-c2f5-5555-8d1f-4fda0fec0e9d_0.png")
    # print(r.content)

    image = crop_image(
        image="https://sfile.chatglm.cn/testpath/4f520e7f-c2f5-5555-8d1f-4fda0fec0e9d_0.png",
        height=950,
        debug=True
    )

    print(crop_image_and_upload(
        image="https://sfile.chatglm.cn/testpath/4f520e7f-c2f5-5555-8d1f-4fda0fec0e9d_0.png",
        height=950,
        debug=True))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : replicate_types
# @Time         : 2024/11/15 18:32
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : 

from meutils.pipe import *

FEISHU_URL = "https://xchatllm.feishu.cn/sheets/GYCHsvI4qhnDPNtI4VPcdw2knEd?sheet=QHbR7a"


class ReplicateRequest(BaseModel):
    ref: str = "black-forest-labs/flux-schnell"
    input: Optional[Dict[str, Any]] = None  # {"prompt": "A majestic lion", "num_outputs": 2}



class ReplicateResponse(BaseModel):
    model: str = "🔥"

    id: str = Field(default_factory=shortuuid.random)
    status: str = "starting"  # succeeded

    input: Optional[Any] = None  # 兼容任意结构体
    output: Optional[Any] = None

    logs: str = ""
    error: Optional[str] = None
    metrics: Optional[Any] = None

    created_at: str = Field(default_factory=lambda: datetime.datetime.today().isoformat())  # "2024-11-19T03:11:22.795Z"
    started_at: Optional[str] = None
    completed_at: Optional[str] = None

    """
    {
    "get": "https://api.replicate.com/v1/predictions/pab8srw8jhrm20cj1e7s0d8kf4",
    "cancel": "https://api.replicate.com/v1/predictions/pab8srw8jhrm20cj1e7s0d8kf4/cancel"
    }
    """
    urls: Optional[Dict[str, str]] = None

    data_removed: bool = False  # 移除任务
    version: str = ""

    # token
    system_fingerprint: Optional[str] = None

    def __init__(self, /, **data: Any):
        super().__init__(**data)

    class Config:
        # 允许额外字段，增加灵活性
        extra = 'allow'




if __name__ == '__main__':
    from meutils.db.redis_db import redis_client

    r = ReplicateRequest(
        input=ReplicateSDKRequest(
            ref="stability-ai/stable-diffusion:db21e45d3f7023abc2a46ee38a23973f6dce16bb082a930b0c49861f96d1e5bf",
            input={"prompt": "A majestic lion", "num_outputs": 2}
        )
    )

    # print(r.model_dump_json(indent=4))

    # print(ReplicateResponse())

    url = "https://oss.ffire.cc/files/kling_watermark.png"

    response = ReplicateResponse(output=[url])
    print(response.model_dump_json(indent=4))

    # redis_client.set(response.id, response.model_dump_json(indent=4), ex=3600)

    # redis_client.set(response.id, response, ex=3600)

    data = {
        "status": "starting",
        "urls": {
            "get": "https://api.chatfire.cn/v1/predictions/d42c7e90a577bdec0a68797e77a8e0d8"
        },
        "id": "d42c7e90a577bdec0a68797e77a8e0d8",
        "model": "black-forest-labs/flux-1.1-pro",
        "error": None,
        "output": None,
        "data_removed": False,
        "created_at": "2024-11-19T03:11:22.795Z",
        "version": "dp-a956b5a516d14ae1a2b108b3a81e8306",
        "input": {
            "num_inference_steps": 28,
            "num_outputs": 1,
            "prompt": "a cat",
            "prompt_strength": 0.8,
            "aspect_ratio": "1:1",
            "megapixels": "1",
            "output_quality": 80,
            "go_fast": True,
            "guidance": 3
        },
        "logs": ""
    }

    print(ReplicateResponse(**data))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : reload
# @Time         : 2023/12/27 11:20
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : 保持常驻状态并刷新

from meutils.pipe import *
from meutils.decorators.retry import retrying
from meutils.playwright_utils import get_new_browser

from playwright.async_api import Playwright, async_playwright


# @retrying
# async def _refresh_cookies(url, headless=True, storage_state: Optional[Path] = '', timeout: int = 0, delay: int = 1):
#     async with async_playwright() as playwright:
#         browser = await playwright.chromium.launch(headless=headless)
#         while delay:
#             context = await browser.new_context(storage_state=storage_state if Path(storage_state).exists() else None)
#
#             page = await context.new_page()
#
#             await page.goto(url)
#             await page.wait_for_load_state(state='load')
#             await page.wait_for_load_state(state='networkidle')
#             await page.wait_for_load_state(state='domcontentloaded')
#             await page.wait_for_timeout(timeout=timeout * 1000)
#
#             await asyncio.sleep(delay)
#             await page.reload()
#             await context.storage_state(path=storage_state)  # 保存状态文件，覆盖更新
#             logger.success(f"刷新cookies成功: {storage_state}")


@retrying
async def _refresh_cookies(
        url: str,
        headless=True,
        storage_state: Optional[Path] = '',
        timeout: int = 1,
        delay: int = 5,
        only_once: bool = True
):
    browser = await get_new_browser(headless=headless)

    while True:
        context = await browser.new_context(storage_state=storage_state if Path(storage_state).exists() else None)
        page = await context.new_page()

        await page.goto(url)
        await page.wait_for_load_state(state='load')
        await page.wait_for_load_state(state='networkidle')
        await page.wait_for_load_state(state='domcontentloaded')
        await page.wait_for_timeout(timeout=timeout * 1000)

        await page.reload()
        await asyncio.sleep(delay)

        await context.storage_state(path=storage_state)  # 保存状态文件，覆盖更新
        logger.success(f"刷新cookies成功: {storage_state}")

        await context.close()
        await page.close()

        if only_once: break  # 默认一次


def refresh_cookies(
        url: str = "https://kimi.moonshot.cn/",
        headless: bool = True,
        storage_state: str = 'kimi*.json',
        timeout: int = 3,
        delay: int = 5,
        only_once: bool = True
):
    """刷新cookies 后台常驻"""

    ps = Path(Path(storage_state).parent).glob(Path(storage_state).name)

    fn = partial(_refresh_cookies, url=url, headless=headless, timeout=timeout, delay=delay, only_once=only_once)

    tasks = [fn(storage_state=storage_state) for storage_state in ps]
    tasks | xAsyncio()


if __name__ == '__main__':
    refresh_cookies(storage_state='kimi_cookies.json', headless=False, only_once=False)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : MeUtils.
# @File         : pdf
# @Time         : 2022/6/30 下午3:41
# @Author       : yuanjie
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  :

from meutils.pipe import *


def extract_text(file_or_text):
    import fitz  # pymupdf 速度更快

    _bytes = b''
    if isinstance(file_or_text, (str, Path)) and Path(file_or_text).is_file():
        _bytes = Path(file_or_text).read_bytes()
    elif isinstance(file_or_text, bytes):
        _bytes = file_or_text

    else:
        return file_or_text

    return '\n'.join(page.get_text().strip() for page in fitz.Document(stream=_bytes))


def pdf2text(file_or_dir_or_files, n_jobs=3):
    if isinstance(file_or_dir_or_files, str) or not isinstance(file_or_dir_or_files, Iterable):
        p = Path(file_or_dir_or_files)
        if p.is_file():
            file_or_dir_or_files = [p]
        elif p.is_dir():
            file_or_dir_or_files = p.glob('*.pdf')
        else:
            raise ValueError('无效文件')

    _ = file_or_dir_or_files | xJobs(lambda p: (p, extract_text(p)), n_jobs)

    return pd.DataFrame(_, columns=['filename', 'text'])


def pdf2table(filename, pages='1', suppress_stdout=False, **kwargs):
    import camelot
    tables = camelot.read_pdf(filename, pages=pages, suppress_stdout=suppress_stdout, **kwargs)
    for t in tables:
        yield t.df


def doc2text(filename):
    pass


def doc2text(filename):
    pass


def extract_images_from_pdf(file, output: Optional[str] = None):
    import fitz

    # 打开PDF文件

    pdf_document = fitz.open(file)

    # 遍历每一页

    for page_number in range(pdf_document.page_count):

        page = pdf_document.load_page(page_number)

        image_list = page.get_images(full=True)

        # 遍历每个图像

        for image_index, img in enumerate(image_list):
            xref = img[0]

            base_image = pdf_document.extract_image(xref)

            image_bytes = base_image["image"]

            image_ext = base_image["ext"]

            image_filename = f"{output or ''}/image{page_number + 1}_{image_index + 1}.{image_ext}"
            Path(image_filename).parent.mkdir(parents=True, exist_ok=True)

            # 将图像写入文件

            with open(image_filename, "wb") as image_file:
                image_file.write(image_bytes)


if __name__ == '__main__':
    with timer():
        # r = extract_text('上海证券交易所证券交易业务指南第8号——科创板股票做市（上证函〔2022〕1155号 20220715）-1757338961901 (1).pdf')
        r = extract_text('非上市公司股权估值指引（2025年修订 中证协发〔2025〕86号 20250425 20250601）-1757078360106.pdf')

        # r = extract_images_from_pdf('《锋利的jQuery》(高清扫描版-有书签)_副本_加水印.pdf', 'images')

    # import tiktoken
    # print(tiktoken.encoding_for_model('gpt-3.5-turbo'))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : image_types
# @Time         : 2024/8/21 14:18
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : todo: 通用比例适配

from meutils.pipe import *
from meutils.str_utils import parse_url, parse_command_string
from meutils.math_utils import size2aspect_ratio

from pydantic import constr
from openai.types import ImagesResponse as _ImagesResponse, Image

# {v:k for k, v in ASPECT_RATIOS.items()}
ASPECT_RATIOS = {
    "1:1": "1024x1024",

    "1:2": "512x1024",
    "2:1": "1024x512",

    '2:3': "768x512",
    '3:2': "512x768",

    "4:3": "1280x960",  # "1024x768"
    "3:4": "960x1280",

    "5:4": "1280x960",
    "4:5": "960x1280",

    "16:9": "1366x768",  # "1024x576"
    "9:16": "768x1366",

    "21:9": "1344x576",

    '1024x1024': '1:1',
    '512x1024': '1:2',
    '1024x512': '2:1',
    '768x512': '2:3',
    '512x768': '3:2',

    '1280x960': '4:3',
    '960x1280': '3:4',
    "1024x768": '4:3',
    "768x1024": '3:4',

    '1366x768': '16:9',

    '768x1366': '9:16',
    '1024x576': '16:9',
    '576x1024': '9:16',

    '1344x576': '21:9'

}


class ImagesResponse(_ImagesResponse):
    created: int = Field(default_factory=lambda: int(time.time()))

    data: Optional[List[Union[Image, dict]]] = []

    image: Optional[Union[str, List[str]]] = None

    metadata: Optional[Any] = None

    timings: Optional[Any] = None

    def __init__(self, /, **data: Any):
        super().__init__(**data)
        if not self.data and self.image is not None:
            if isinstance(self.image, str):
                self.image = [self.image]

            self.data = [{"url": image} for image in self.image]

        elif self.data and "imageURL" in self.data[0]:
            self.image = [d["imageURL"] for d in self.data]

    # class Config:
    #     extra = "allow"


class ImageRequest(BaseModel):  # openai
    """
    图生图 两种方式： prompt + controls

        background: Optional[Literal["transparent", "opaque", "auto"]] | NotGiven = NOT_GIVEN,
        model: Union[str, ImageModel, None] | NotGiven = NOT_GIVEN,
        output_compression: Optional[int] | NotGiven = NOT_GIVEN,
        output_format: Optional[Literal["png", "jpeg", "webp"]] | NotGiven = NOT_GIVEN,
        partial_images: Optional[int] | NotGiven = NOT_GIVEN,

    """
    model: str = ''

    prompt: constr(min_length=1, max_length=10240) = " "

    moderation: Optional[Literal["low", "auto"]] = None

    style: Optional[Union[str, Literal["vivid", "natural"]]] = None
    background: Optional[Union[str, Literal["transparent", "opaque", "auto"]]] = None
    input_fidelity: Optional[Union[str, Literal["high", "low"]]] = None
    quality: Optional[Union[str, Literal["standard", "low", "medium", "high", "auto"]]] = None

    # 测试默认值 Optional[Literal["256x256", "512x512", "1024x1024", "1792x1024", "1024x1792"]]
    n: Optional[int] = 1
    size: Optional[str] = '1024x1024'  # null auto

    output_format: Optional[Literal["png", "jpeg", "webp"]] = None
    response_format: Optional[Literal["url", "b64_json", "oss_url", "glb", "stl"]] = "url"

    seed: Optional[int] = None
    stream: Optional[bool] = None

    # oneapi https://github.com/QuantumNous/new-api/blob/main/dto/dalle.go
    extra_fields: Optional[Any] = None  ###

    negative_prompt: Optional[str] = None
    guidance: Optional[float] = None
    steps: Optional[int] = None

    controls: Optional[dict] = None  # 额外参数

    safety_tolerance: Optional[int] = None

    aspect_ratio: Optional[str] = None

    user: Optional[str] = None

    image: Optional[Union[str, List[str], bytes, List[bytes]]] = None  # url b64 file_bytes
    watermark: Optional[bool] = None

    def __init__(self, /, **data: Any):
        super().__init__(**data)
        # 规避空字符
        self.style = self.style or None
        self.quality = self.quality or None
        self.background = self.background or None
        self.input_fidelity = self.input_fidelity or None

        if not self.model.startswith(("doubao-seed",)):

            if self.aspect_ratio:  # 适配比例
                self.size = ASPECT_RATIOS.get(self.aspect_ratio, '1024x1024')

            elif self.size == 'auto':
                self.size = self.aspect_ratio = None

            elif self.size:  # 适配尺寸
                # if self.size.lower().endswith('k'):
                #     size = int(self.size.lower().split('k')[0]) * 1024
                #     self.size = f"{size}x{size}"
                self.aspect_ratio = size2aspect_ratio(self.size)
                self.size = self.size if 'x' in self.size else '512x512'

    @cached_property
    def image_urls(self) -> List[str]:
        if self.image:
            if isinstance(self.image, str):
                return [self.image]
            else:
                return self.image
        else:
            image, _ = self.image_and_prompt
            if image:
                return [image]

        return []

    @cached_property
    def image_and_prompt(self):  # image prompt 目前是单图
        if self.prompt.startswith('http') and (prompts := self.prompt.split(maxsplit=1)):
            if len(prompts) == 2:
                self.prompt = prompts[-1]
                return prompts
            else:
                return prompts + [' ']  # 只有 单url

        elif "http" in self.prompt and (images := parse_url(self.prompt)):
            self.prompt = self.prompt.replace(images[0], "")
            return images[0], self.prompt

        else:
            return None, self.prompt

    def prompt2aspect_ratio(self, aspect_ratios):  # 提示词优先级最高：从支持的比例中选择匹配
        for aspect_ratio in aspect_ratios:
            if aspect_ratio in self.prompt:
                return aspect_ratio

    class Config:
        extra = "allow"

        # frozen = True
        # populate_by_name = True

        json_schema_extra = {
            "examples": [
                {
                    "model": "stable-diffusion-3-medium",  # sd3
                    "prompt": "画条狗",
                },
            ]
        }


class ImageEditRequest(BaseModel):
    model: Union[str, Literal["dall-e-2", "dall-e-3", "gpt-image-1"]]

    # image: Union[FileTypes, SequenceNotStr[FileTypes]],
    # prompt: str,
    # mask: FileTypes | NotGiven = NOT_GIVEN,

    prompt: str
    image: Any  # 图片

    mask: Optional[Any] = None  # 图片

    background: Optional[Union[str, Literal["transparent", "opaque", "auto"]]] = None
    input_fidelity: Optional[Union[str, Literal["high", "low"]]] = None
    quality: Optional[Union[str, Literal["standard", "low", "medium", "high", "auto"]]] = None

    n: Optional[int] = 1
    size: Optional[
        Union[str, Literal["256x256", "512x512", "1024x1024", "1536x1024", "1024x1536", "auto"]]] = "1024x1024"

    aspect_ratio: Optional[str] = None

    user: Optional[str] = None
    stream: Optional[bool] = None

    response_format: Optional[Literal["url", "b64_json"]] = None
    output_format: Optional[Literal["png", "jpeg", "webp"]] = None

    # output_compression: Optional[int] | NotGiven = NOT_GIVEN,
    # partial_images: Optional[int] | NotGiven = NOT_GIVEN,

    def __init__(self, /, **data: Any):
        super().__init__(**data)
        # 规避空字符
        self.quality = self.quality or None
        self.background = self.background or None
        self.input_fidelity = self.input_fidelity or None

        if not isinstance(self.image, list):
            self.image = [self.image]

        if not self.model.startswith(("doubao-seed",)):

            if self.aspect_ratio:  # 适配比例
                self.size = ASPECT_RATIOS.get(self.aspect_ratio, '1024x1024')

            elif self.size == 'auto':
                self.size = self.aspect_ratio = None

            elif self.size:  # 适配尺寸
                # if self.size.lower().endswith('k'):
                #     size = int(self.size.lower().split('k')[0]) * 1024
                #     self.size = f"{size}x{size}"
                self.aspect_ratio = size2aspect_ratio(self.size)
                self.size = self.size if 'x' in self.size else '512x512'


class FalImageRequest(ImageRequest):
    prompt: str
    seed: Optional[int] = None
    sync_mode: Optional[bool] = None
    num_images: Optional[int] = 1
    enable_safety_checker: Optional[bool] = True
    safety_tolerance: Optional[str] = "6"
    output_format: Optional[str] = "png"
    aspect_ratio: Literal['21:9', '16:9', '4:3', '1:1', '3:4', '9:16', '9:21'] = "1:1"
    raw: Optional[bool] = None


class FluxImageRequest(ImageRequest):
    model: str = 'flux1.0-schnell'
    image_size: Optional[str] = None

    num_inference_steps: Optional[int] = None

    def __init__(self, /, **data: Any):
        super().__init__(**data)
        self.image_size = self.size


class TogetherImageRequest(ImageRequest):  # together
    model: str = 'flux1.0-turbo'
    steps: Optional[int] = None

    height: int = 1024
    width: int = 1024

    def __init__(self, /, **data: Any):
        super().__init__(**data)
        try:
            self.width, self.height = map(int, self.size.split('x'))
        except Exception as e:
            logger.error(e)

        if "pro" in self.model:
            self.model = 'flux1.1-pro'


class SDImageRequest(ImageRequest):
    model: str = "stable-diffusion"
    image_size: Optional[str] = None  # 512x512, 512x1024, 768x512, 768x1024, 1024x576, 576x1024
    batch_size: Optional[int] = None
    guidance_scale: Optional[float] = 7.5
    num_inference_steps: Optional[int] = 25

    image: Optional[str] = None  # base64

    def __init__(self, /, **data: Any):
        super().__init__(**data)
        self.n = self.batch_size or self.n


class HunyuanImageRequest(ImageRequest):
    model: str = "hunyuan"
    size: Literal["1:1", "3:4", "4:3", "9:16", "16:9"] = "1:1"
    style: Optional[Literal[
        '摄影',
        '童话世界',
        '奇趣卡通',
        '二次元',
        '纯真动漫',

        '清新日漫',
        '3D'
        '赛博朋克',
        '像素',
        '极简',

        '复古',
        '暗黑系',
        '波普风',
        '中国风',
        '国潮',

        '糖果色',
        '胶片电影',
        '素描',
        '水墨画',
        '油画',

        '水彩',
        '粉笔',
        '粘土',
        '毛毡',
        '贴纸',

        '剪纸',
        '刺绣',
        '彩铅',
        '梵高',
        '莫奈',

        '穆夏',
        '毕加索',
    ]] = None

    def __init__(self, /, **data: Any):
        super().__init__(**data)


class KlingImageRequest(ImageRequest):
    model: str = "kling"
    n: Optional[int] = 4
    size: str = "1:1"

    # 图生图
    image: Optional[str] = None
    image_fidelity: Optional[float] = None

    def __init__(self, /, **data: Any):
        super().__init__(**data)
        self.size = "1:1" if self.size not in {"1:1", "2:3", "3:2", "3:4", "4:3", "9:16", "16:9"} else self.size


class KolorsRequest(ImageRequest):
    model: Union[str, Literal["kolors-1.0", "kolors-1.5"]] = "kolors-1.0"
    n: Optional[int] = 4

    """
    1:1(1024*1024)
    4:3(1152*896)
    3:4(768*1024)
    16:9(1024 576)
    9:16(576 1024)
    3:2(1024*640)
    2:3(640*1024)
    """
    size: Literal[
        "1024x1024", "1152x896", "768x1024", "1024x576", "576x1024", "1024x640", "640x1024"
    ] = "1024x1024"

    # 图生图
    image: Optional[str] = None
    image_fidelity: Optional[float] = None

    def __init__(self, /, **data: Any):
        super().__init__(**data)


class CogviewImageRequest(ImageRequest):
    model: str = "cogview-3"
    size: Optional[Literal["1024x1024", "768x1344", "864x1152", "1344x768", "1152x864", "1440x720", "720x1440"]] = None


class StepImageRequest(ImageRequest):
    image_size: str
    batch_size: int
    guidance_scale: float
    num_inference_steps: int


class RecraftImageRequest(ImageRequest):
    transform_model: str = "recraftv3"  # recraftv3-halloween
    image_type: Optional[
        Union[
            str,
            Literal[
                'any',
                'digital_illustration',
                'digital_illustration',
                'digital_illustration_pixel_art',
                'digital_illustration_3d',
                'digital_illustration_psychedelic',
                'digital_illustration_hand_drawn',
                'digital_illustration_grain',
                'digital_illustration_glow',
                'digital_illustration_80s',
                'digital_illustration_watercolor',
                'digital_illustration_voxel',
                'digital_illustration_infantile_sketch',
                'digital_illustration_2d_art_poster',
                'digital_illustration_kawaii',
                'digital_illustration_halloween_drawings',
                'digital_illustration_2d_art_poster_2',
                'digital_illustration_engraving_color',
                'digital_illustration_flat_air_art',
                'digital_illustration_hand_drawn_outline',
                'digital_illustration_handmade_3d',
                'digital_illustration_stickers_drawings',

                'realistic_image',
                'realistic_image_mockup',
                'realistic_image_b_and_w',
                'realistic_image_enterprise',
                'realistic_image_hard_flash',
                'realistic_image_hdr',
                'realistic_image_natural_light',
                'realistic_image_studio_portrait',
                'realistic_image_motion_blur',

                'vector_illustration',
                'vector_illustration_seamless',
                'vector_illustration_line_art',
                'vector_illustration_doodle_line_art',
                'vector_illustration_flat_2',
                'vector_illustration_70s',
                'vector_illustration_cartoon',
                'vector_illustration_kawaii',
                'vector_illustration_linocut',
                'vector_illustration_engraving',
                'vector_illustration_halloween_stickers',
                'vector_illustration_line_circuit',

            ]]] = "any"
    user_controls: dict = {}
    layer_size: Optional[dict] = None
    random_seed: Optional[int] = None
    num_images_per_prompt: Optional[int] = None

    def __init__(self, /, **data: Any):
        super().__init__(**data)
        self.num_images_per_prompt = self.n
        self.random_seed = self.seed

        max_size = 2048  # 最大像素
        w, h = map(int, self.size.split('x'))
        scale_factor = max_size // max(w, h)
        w, h = w * scale_factor, h * scale_factor

        self.layer_size = {"width": w, "height": h}

        self.image_type = self.style or self.image_type
        if self.image_type in {"natural", }:
            self.image_type = "any"


class ImageProcessRequest(BaseModel):
    task: Optional[str] = None
    image: str


BAIDU_TASKS = {
    'matting': 'matting',
    'ai-matting': 'matting',
    'ai-removewatermark': 'removewatermark'  # TODO： 变清晰
}


class BaiduImageProcessRequest(ImageProcessRequest):
    task: Optional[str] = None

    def __init__(self, /, **data: Any):
        super().__init__(**data)
        self.task = BAIDU_TASKS.get(self.task, self.task)


HUNYUAN_TASKS = {
    'clarity': 'clarity',
    'removewatermark': 'removewatermark',
    'style': 'style',
}


class HunyuanImageProcessRequest(ImageProcessRequest):
    task: Optional[Literal[
        'removewatermark',
        'style',
        'clarity',
    ]] = 'removewatermark'
    style: Optional[Literal[
        '摄影',
        '童话世界',
        '奇趣卡通',
        '二次元',
        '纯真动漫',

        '清新日漫',
        '3D'
        '赛博朋克',
        '像素',
        '极简',

        '复古',
        '暗黑系',
        '波普风',
        '中国风',
        '国潮',

        '糖果色',
        '胶片电影',
        '素描',
        '水墨画',
        '油画',

        '水彩',
        '粉笔',
        '粘土',
        '毛毡',
        '贴纸',

        '剪纸',
        '刺绣',
        '彩铅',
        '梵高',
        '莫奈',

        '穆夏',
        '毕加索',
    ]] = None

    def __init__(self, /, **data: Any):
        super().__init__(**data)
        self.task = HUNYUAN_TASKS.get(self.task, self.task)


TEXTIN_TASKS = {
    # 文本解析
    "image-to-markdown": "pdf_to_markdown",
    "pdf-to-markdown": "pdf_to_markdown",
    "textin-pdf-to-markdown": "pdf_to_markdown",

    # 去水印
    'textin-removewatermark': 'watermark-remove',

    'textin-ocr': 'text_recognize_3d1',
    'text-recognize': 'text_recognize_3d1',

    # 图片提取表格
    "textin-table": "table",

    "textin-crop-enhance": "crop_enhance_image",

    # 票据识别
    "textin-bill-recognize": "bill_recognize_v2",
}


class TextinImageProcessRequest(ImageProcessRequest):

    def __init__(self, /, **data: Any):
        super().__init__(**data)

        self.task = TEXTIN_TASKS.get(self.task.replace('_', '-'), self.task)


class ImageProcess(BaseModel):
    model: Literal[
        "remove-watermark",
        "remove-watermark-hunyuan",
        "remove-watermark-textin",

        "clarity",
        "clarity-hunyuan",
        "clarity-baidu",

        "expand",
        "rmbg-2.0"
    ]
    image: Union[str, bytes]
    mask: Optional[str] = None

    style: Optional[str] = None
    aspect_ratio: Union[str, Literal["1:1", "4:3", "3:4"]] = "1:1"  # 扩图

    response_format: Literal["url", "b64_json"] = "url"

    # class Config:
    #     extra = "allow"


if __name__ == '__main__':
    # print(ASPECT_RATIOS.items())

    # ImageRequest(quality=1)
    @lru_cache()
    def f(r):
        return r


    # f(FluxImageRequest(prompt="xx"))

    # from openai import OpenAI
    # from meutils.llm.openai_utils import to_openai_images_params
    #
    # data = to_openai_images_params(ImageRequest(prompt="a dog"))
    #
    # print(data)
    #
    # OpenAI().images.generate(**ImageRequest(prompt="a dog").model_dump())

    # print(KlingImageRequest())

    # print(ImagesResponse(data=[{'url': 1}]))

    # print(RecraftImageRequest(prompt="").model_dump_json())
    # print(RecraftImageRequest(prompt=""))

    prompt = "https://oss.ffire.cc/files/kling_watermark.png 带个眼镜"
    # prompt = "带个眼镜 https://oss.ffire.cc/files/kling_watermark.png"
    # prompt = "https://oss.ffire.cc/files/kling_watermark.png"
    # prompt = "画条狗"

    request = ImageRequest(
        prompt=prompt,

        # size="16x9",
        # size="1K",
        size="2K",

        # size="auto",

        # aspect_ratio="16:9"
    )

    # "sequential_image_generation": "auto",
    # "sequential_image_generation_options": {
    #     "max_images": 4
    # },

    #
    # print(request.prompt)
    #
    # print(request.image_urls)
    # print(request.image_and_prompt)
    # print(request.prompt)

    # data = {"image[]": "xxx"}
    # r = ImageRequest(**data)
    #
    # data = {
    #     "model": "flux-kontext-pro",
    #     "prompt": "a cat and a dog",
    #     "size": "512x1024",
    #     # "aspect_ratio": "16:9"
    # }
    #
    # dd = {
    #     "model": "flux-kontext-pro",
    #     "prompt": "a cat and a dog",
    #     "size": "5121x1024",
    #     # "aspect_ratio": "16:9"
    # }
    #
    # r = ImageRequest(**data)

    # print(ImagesResponse())

    # print(request)

    print(dict(Image()))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : common
# @Time         : 2024/9/21 14:02
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  :
import pandas as pd

from meutils.pipe import *


def to_html_plus(df, title='Title', subtitle='Subtitle', return_filename=False):
    from jinja2 import Environment, PackageLoader
    env = Environment(loader=PackageLoader('meutils'))
    template = env.get_template('df_html.j2')

    html_content = template.render(df_to_html=df.to_html(), title=title, subtitle=subtitle)
    if return_filename:
        with tempfile.NamedTemporaryFile(mode='w+', suffix='.html', delete=False) as file:
            # logger.debug(file.name)
            file.write(html_content)
            file.seek(0)
            return file.name
    return html_content


if __name__ == '__main__':
    to_html_plus(pd.DataFrame(range(10)))


#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : MeUtils.
# @File         : try
# @Time         : 2021/4/2 11:03 上午
# @Author       : yuanjie
# @WeChat       : 313303303
# @Software     : PyCharm
# @Description  :
from meutils.pipe import *


def wecom_hook(title='Task Done', text=None, hook_url=None):
    """装饰器里不可变参数

    :param title:
    :param text: 如果为空，用函数返回值填充【text覆盖函数返回值】
    :param hook_url: hook_url或者群名称
    :return:
    """

    @wrapt.decorator
    def wrapper(wrapped, instance, args, kwargs):
        s = time.time()
        r = wrapped(*args, **kwargs)
        e = time.time()

        mins = (e - s) // 60

        logger.info(f"{title} done in {mins} m")

        return r

    return wrapper


def wecom_catch(hook_url=None, more_info=True):
    @wrapt.decorator
    def wrapper(wrapped, instance, args, kwargs):
        try:
            return wrapped(*args, **kwargs)

        except Exception as e:
            info = traceback.format_exc() if more_info else e
            text = f"""
            ```
            {info.strip()}
            ```
            """.strip()

    return wrapper


if __name__ == '__main__':
    # @feishu_catch()
    # def f():
    #     1 / 0
    #
    #
    # f()

    # @wecom_catch(more_info=False)
    # def f():
    #     1 / 0
    #
    #
    # f()

    @wecom_hook('catch_hook测试', text="TEXT")
    @wecom_catch()
    def f():
        # 1 / 0
        print(time.time())
        return 'RES'


    f()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : user
# @Time         : 2024/7/19 14:58
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : todo: redis缓存, 通过数据库获取 用户余额，补偿余额【扣费逻辑：用户余额够就直接计费，先请求计费+创建任务】，计费函数可返回用户信息
import json
import os

from meutils.pipe import *
from meutils.schemas.oneapi import BASE_URL
from meutils.notice.feishu import send_message
from meutils.caches import cache, rcache

# https://api.chatfire.cn/api/user/814

token = os.environ.get("CHATFIRE_ONEAPI_TOKEN")

headers = {
    "Authorization": f"Bearer {token}",
    'rix-api-user': '1',
    'new-api-user': '1',
    'one-api-user': '1'

}


# https://api.chatfire.cn/api/user/token 刷新token
# https://api.chatfire.cn/api/user/1
# async def get_user(user_id):
#     async with httpx.AsyncClient(base_url=BASE_URL, headers=headers) as client:
#         response = await client.get(f"/api/user/{user_id}")
#         logger.debug(response.text)
#
#         if response.is_success:
#             data = response.json()
#             return data
# @rcache(ttl=7 * 24 * 3600)
async def get_api_key_log(api_key: str) -> Optional[list]:  # 日志查询会超时：为了获取 user_id, todo缓存 永久缓存 sk => user
    try:
        async with httpx.AsyncClient(base_url=BASE_URL) as client:
            response = await client.get("/api/log/token", params={"key": api_key})
            response.raise_for_status()
            data = response.json()
            if onelog := data['data'][:1]:
                return onelog
    except Exception as e:
        logger.error(e)
        send_message(f"获取api-key日志失败：{api_key}", title=__name__)
        return


async def get_user(user_id):
    async with httpx.AsyncClient(base_url=BASE_URL, headers=headers, timeout=30) as client:
        response = await client.get(f"/api/user/{user_id}")

        if response.is_success:
            data = response.json()
            return data


async def get_user_money(api_key):
    if onelog := await get_api_key_log(api_key):
        onelog = onelog[0]
        user_id = onelog['user_id']

        data = await get_user(user_id)
        logger.debug(data)
        if data:
            username = data['data']['username']
            quota = data['data']['quota']
            return quota / 500000  # money

    logger.debug(onelog)


# 补偿
async def put_user(payload, quota: float = 0):
    async with httpx.AsyncClient(base_url=BASE_URL, headers=headers) as client:
        payload['quota'] = quota  # 1块钱对应50万

        response = await client.put("/api/user/", json=payload)
        # logger.debug(response.text)
        # logger.debug(response.status_code)

        return response.json()


async def update_user_for_refund(user_id, quota: int = 0):  # 1块钱对应50万tokens
    data = await get_user(user_id)

    if data := data['data']:
        data['quota'] += quota

    async with httpx.AsyncClient(base_url=BASE_URL, headers=headers) as client:
        response = await client.put("/api/user/", json=data)

        return response.json()


@cache()
@rcache()
async def get_user_from_api_key(api_key):
    async with httpx.AsyncClient(base_url=BASE_URL, timeout=15) as client:
        response = await client.get("/api/log/token", params={"key": api_key})
        response.raise_for_status()
        data = response.json()
        # logger.debug(data)

        if data['data'] and (onelog := data['data'][0]):
            return onelog


async def get_user_for_quota(api_key):
    async with httpx.AsyncClient(base_url=BASE_URL) as client:
        response = await client.get("/api/user/self", headers=headers)
        response.raise_for_status()
        data = response.json()
        # logger.debug(data)

        return data


if __name__ == '__main__':
    pass
    # api-key => get_one_log => get_user => put_user
    # arun(get_user(10988))
    # payload = arun(get_user(1))
    # print(payload)
    # arun(put_user(payload['data'], -1))
    # arun(get_api_key_log("sk-LtwE539cQFNJTRsj3w6zoUlp7mI0Wq5XhgwtDrkGqfSdJx1I"))

    # arun(get_api_key_log(os.getenv("OPENAI_API_KEY")))



    # arun(get_user_money("sk-"))
    arun(get_user_from_api_key('sk-LtwE539cQFNJTRsj3w6zoUlp7mI0Wq5XhgwtDrkGqfSdJx1I'))

    # arun(get_user_for_quota("sk-"))

    # arun(get_user(11327))

    # arun(update_user_for_refund(2, quota=73065879))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : mecharts
# @Time         : 2023/4/7 11:58
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : 

from meutils.pipe import *

from pyecharts import options as opts
from pyecharts.charts import Bar, WordCloud, HeatMap, Polar, Graph


class Chart(object):

    def __init__(self, width='1000px', height='400px', title='', render='notebook', jupyter_port=9955):
        self.init_opts = opts.InitOpts(width, height)
        self.title_opts = opts.TitleOpts(title=title)
        self.render = render  # .html
        if self.render == 'notebook':
            self.set_jupyter(jupyter_port)

    def graph(self, nodes, links, **kwargs):  # 共现网络
        """

        :param nodes: [{"name": "节点1", 'symbolSize': 32}] # opts.GraphNode
        :param links: [{"source": "节点1", "target": "节点2", "value": "关系", "symbolSize": "词频"}] # opts.GraphLink
        :return:
        """

        # 展示图表
        graph = Graph(self.init_opts)

        # graph.set_global_opts(visualmap_opts=opts.VisualMapOpts(max_=120))  # 根据节点的value值映射，最大120，因为有120回
        graph.add(
            nodes=nodes,
            links=links,
            series_name='',
            repulsion=256,
            # layout='force',
            # edge_length=[1, 100],
            # edge_label=opts.LabelOpts(is_show=False, position="middle", formatter="{c}"),
            # itemstyle_opts=opts.ItemStyleOpts(border_color='blue', opacity='0.9'),  # 节点样式设置
            # label_opts=opts.LabelOpts(is_show=True, position='inside', color='red')  # 节点标签（人物名称）设置
            **kwargs
        )
        return self.return_func(graph)

    def wordcloud(self, data_pair, shape='circle', **kwargs):
        """

        :param data_pair: [('周杰伦', 100)]
        :param shape: ['circle', 'cardioid', 'diamond', 'triangle-forward', 'triangle', 'pentagon', 'star']
        :param kwargs:
        :return:
        """
        if isinstance(data_pair, dict):
            data_pair = data_pair.items()

        wc = WordCloud(self.init_opts)
        wc.set_global_opts(
            title_opts=opts.TitleOpts(title='词云'),
            # visualmap_opts=opts.VisualMapOpts(),
            # tooltip_opts=opts.TooltipOpts(is_show=True)
        )
        wc.add(series_name='', data_pair=data_pair, shape=shape, **kwargs)
        return self.return_func(wc)

    def bar(self, xaxis_data, name2ydata, render='notebook', **kwargs):
        bar = Bar(init_opts=self.init_opts)
        bar.set_global_opts(title_opts=self.title_opts)
        bar.add_xaxis(xaxis_data)

        for name, ydata in name2ydata.items() if isinstance(name2ydata, dict) else name2ydata:
            bar.add_yaxis(name, ydata)

        return self.return_func(bar)

    def return_func(self, chart):
        render = self.render
        if render == 'notebook':
            return chart.render_notebook()
        elif render:
            return chart.render(render)  # html地址
        return chart

    @staticmethod
    def set_jupyter(port=9955):
        """插件教程 https://zhuanlan.zhihu.com/p/408166097?utm_id=0"""
        # 只需要在顶部声明 CurrentConfig.ONLINE_HOST 即可
        from pyecharts.globals import CurrentConfig, OnlineHostType

        # OnlineHostType.NOTEBOOK_HOST 默认值为 http://localhost:8888/nbextensions/assets/
        CurrentConfig.ONLINE_HOST = OnlineHostType.NOTEBOOK_HOST.replace('8888', str(port))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Project      : AI.  @by PyCharm
# @File         : videos
# @Time         : 2025/5/23 14:13
# @Author       : betterme
# @WeChat       : meutils
# @Software     : PyCharm
# @Description  : 

from meutils.pipe import *

import requests
import json

url = "https://tools.dreamfaceapp.com/dw-server/face/animate_image_web"


def create_task(token: Optional[str] = None):
    headers = {
        'dream-face-web': 'dream-face-web',
        'priority': 'u=1, i',
        'token': 'eyJhbGciOiJIUzI1NiJ9.eyJleHAiOjE3NDgwMDg1NDMsInBheWxvYWQiOnsiaWQiOiI2ODMwMDdhNDI2YmNjZDAwMDhlYjMxMjIiLCJ0aGlyZFBsYXRmb3JtIjoiR09PR0xFIiwidGhpcmRJZCI6IjEwMjg2OTM5NzI4OTkyMjc5NTE5MyIsInBhc3N3b3JkIjpudWxsLCJ0aGlyZEV4dCI6eyJlbWFpbCI6ImpyMTU5NjIyOTQ5ODBAZGp2Yy51ayIsIm5hbWUiOiJ6enkzMDIwOCB5a2Z3eDEyMjgxIiwiZ2VuZGVyIjpudWxsLCJiaXJ0aGRheSI6bnVsbCwibmlja05hbWUiOm51bGwsImdpdmVuTmFtZSI6Inp6eTMwMjA4IiwiZmFtaWx5TmFtZSI6InlrZnd4MTIyODEiLCJwcm9maWxlUGljdHVyZSI6Imh0dHBzOi8vbGgzLmdvb2dsZXVzZXJjb250ZW50LmNvbS9hL0FDZzhvY0tGQXBqUjVZTVhqLXNEYWhWRGw5YVNQT0VuVGlSaXFlMUQ0RTNEU1J5Nno1Wk9FQT1zOTYtYyJ9LCJjcmVhdGVUaW1lIjoxNzQ3OTc4MTQ4NDU0LCJ1cGRhdGVUaW1lRm9ybWF0IjoiMjAyNS0wNS0yMyAxMzoyOTowOC40NTQiLCJkZWxldGUiOm51bGwsImNyZWF0ZVRpbWVGb3JtYXQiOiIyMDI1LTA1LTIzIDEzOjI5OjA4LjQ1NCIsInVwZGF0ZVRpbWUiOjE3NDc5NzgxNDg0NTQsInBsYXRmb3JtVHlwZSI6Mn19.aWdRtZhxch0iQ7xsmR-Im_MLEqgWy7dW8eRigUxz4es',
        'User-Agent': 'Apifox/1.0.0 (https://apifox.com)',
        'content-type': 'application/json'
    }

    payload = {
        "aigc_img_no_save_flag": False,
        "template_id": "6606889f54e4e700070db4b1",
        "app_version": "4.7.1",
        "timestamp": 1747980670819,
        "user_id": "bda0f9897c2aa378c5230cff3418168a",
        "no_water_mark": 1,
        "merge_by_server": False,
        "account_id": "683007a426bccd0008eb3122",
        "pt_infos": [
            {
                "lan": "zh",
                "audio_id": "6629c44502c44c00073515e1",
                "context": "这个屌公司一群傻逼吧",
                "voice_engine_id": "zh-CN-XiaomengNeural",
                "video_url": "https://lmdbk.com/5.mp4"
            }
        ],
        "work_type": "AVATAR_VIDEO",
        "santa_info": {
            "email": "",
            "signature": ""
        },
        "photo_info_list": [
            {
                "photo_path": "",
                "origin_face_locations": [
                    {
                        "left_upper_x": 0,
                        "left_upper_y": 0,
                        "right_width": 1,
                        "down_high": 1
                    }
                ],
                "square_face_locations": [
                    {
                        "left_upper_x": 0,
                        "left_upper_y": 0,
                        "down_high": 1,
                        "right_width": 1
                    }
                ],
                "five_lands": [
                    [
                        [
                            1,
                            1
                        ],
                        [
                            1,
                            1
                        ],
                        [
                            1,
                            1
                        ],
                        [
                            1,
                            1
                        ],
                        [
                            1,
                            1
                        ]
                    ]
                ],
                "face_nums": 1,
                "mask_path": ""
            }
        ],
        "play_types": [
            "VIDEO",
            "PT"
        ],
        "ext": {
            "track_info": "{}",
            "sing_title": "这个屌公司一群傻逼吧",
            "animate_channel": "dynamic"
        }
    }

    response = requests.request("POST", url, headers=headers, data=payload)

    print(response.text)


if __name__ == '__main__':
    create_task()